package sesame.tutorial;

import java.io.File;
import java.net.URL;
import java.util.List;

import org.openrdf.OpenRDFException;
import org.openrdf.model.Statement;
import org.openrdf.model.URI;
import org.openrdf.model.Value;
import org.openrdf.model.ValueFactory;
import org.openrdf.query.BindingSet;
import org.openrdf.query.GraphQuery;
import org.openrdf.query.GraphQueryResult;
import org.openrdf.query.Query;
import org.openrdf.query.QueryLanguage;
import org.openrdf.query.QueryResult;
import org.openrdf.query.TupleQuery;
import org.openrdf.query.TupleQueryResult;
import org.openrdf.query.resultio.sparqlxml.SPARQLResultsXMLWriter;
import org.openrdf.repository.Repository;
import org.openrdf.repository.RepositoryConnection;
import org.openrdf.repository.RepositoryException;
import org.openrdf.repository.sail.SailRepository;
import org.openrdf.rio.RDFFormat;
import org.openrdf.rio.rdfxml.RDFXMLWriter;
import org.openrdf.rio.turtle.TurtleWriter;
import org.openrdf.sail.inferencer.fc.ForwardChainingRDFSInferencer;
import org.openrdf.sail.memory.MemoryStore;

public class TestConstruct {

	static final String inputDataFileName  = "/home/kkyzir/Desktop/SPARQL tutorial/rdf-data/aliceFoaf.rdf";
	
	
	public static void main(String[] args) {
		// Sesame RDF API: http://www.openrdf.org/doc/sesame2/api/

		try {
			//Create a new main memory repository 
			MemoryStore store = new MemoryStore();
			Repository repo = new SailRepository(store);
			repo.initialize();

			//Store file
			try {
				File file = new File(inputDataFileName);
				RDFFormat fileRDFFormat = RDFFormat.N3;
				
				RepositoryConnection con = repo.getConnection();
				//store the file
				con.add(file, null, fileRDFFormat);

			}
			catch (OpenRDFException e) {
				e.printStackTrace();
			}
			catch (java.io.IOException e) {
				// handle io exception
				e.printStackTrace();
			}

			try {
				RepositoryConnection con = repo.getConnection();
					try {

						String queryString = 
							" PREFIX rdf:   <http://www.w3.org/1999/02/22-rdf-syntax-ns#> " +
							" PREFIX foaf: <http://xmlns.com/foaf/0.1/> " +
							" PREFIX ns: <http://example/ns#> " +
							" CONSTRUCT {?x ns:legetai ?y } " +
							" WHERE {?x foaf:name ?y . }";
						
						GraphQuery gQuery = con.prepareGraphQuery(QueryLanguage.SPARQL, queryString);
						
						//TurtleWriter turtleWriter = new TurtleWriter(System.out);
						RDFXMLWriter rdfxmlWriter = new RDFXMLWriter(System.out);
						gQuery.evaluate(rdfxmlWriter);
	
						//GraphQueryResult graphResult = gQuery.evaluate();
						//while (graphResult.hasNext()) {
						//	Statement st = graphResult.next();
						//	System.out.println(st.toString());
						//}
					}
					finally {
						con.close();
					}
				}
				catch (Exception e) {
					//handle exception
					e.printStackTrace();
			}
		} catch (RepositoryException e) {
			// handle exception
			e.printStackTrace();
		}
	}
}
