package sesame.tutorial;

import java.io.File;
import java.net.URL;
import java.util.List;

import org.openrdf.OpenRDFException;
import org.openrdf.model.Statement;
import org.openrdf.model.URI;
import org.openrdf.model.Value;
import org.openrdf.model.ValueFactory;
import org.openrdf.query.BindingSet;
import org.openrdf.query.GraphQueryResult;
import org.openrdf.query.Query;
import org.openrdf.query.QueryLanguage;
import org.openrdf.query.QueryResult;
import org.openrdf.query.TupleQuery;
import org.openrdf.query.TupleQueryResult;
import org.openrdf.query.resultio.sparqlxml.SPARQLResultsXMLWriter;
import org.openrdf.repository.Repository;
import org.openrdf.repository.RepositoryConnection;
import org.openrdf.repository.RepositoryException;
import org.openrdf.repository.sail.SailRepository;
import org.openrdf.rio.RDFFormat;
import org.openrdf.sail.inferencer.fc.ForwardChainingRDFSInferencer;
import org.openrdf.sail.memory.MemoryStore;

public class TestNamedGraphs {

	static final String inputDataFileName1  = "/home/kkyzir/Desktop/SPARQL tutorial/rdf-data/aliceFoaf.rdf";
	static final String inputDataFileName2  = "/home/kkyzir/Desktop/SPARQL tutorial/rdf-data/bobFoaf.rdf";
	
	
	public static void main(String[] args) {
		// Sesame RDF API: http://www.openrdf.org/doc/sesame2/api/

		try {
			//Create a new main memory repository 
			MemoryStore store = new MemoryStore();
			Repository repo = new SailRepository(store);
			repo.initialize();

			//Store file
			try {
				File file1 = new File(inputDataFileName1);
				File file2 = new File(inputDataFileName2);
				RDFFormat fileRDFFormat = RDFFormat.N3; 
				
				ValueFactory f = repo.getValueFactory();
				URI context1 = f.createURI("http://example.org/foaf/aliceFoaf");
				URI context2 = f.createURI("http://example.org/foaf/bobFoaf");
				
				RepositoryConnection con = repo.getConnection();
				
				//load files
				con.add(file1, null, fileRDFFormat, context1);
				con.add(file2, null, fileRDFFormat, context2);

			}
			catch (OpenRDFException e) {
				e.printStackTrace();
			}
			catch (java.io.IOException e) {
				// handle io exception
				e.printStackTrace();
			}
		
	
			try {
				RepositoryConnection con = repo.getConnection();
				try {
			        String queryString1 = 
			        	" PREFIX foaf: <http://xmlns.com/foaf/0.1/> " +
			        	" SELECT ?src ?bobNick " +
			        	" FROM NAMED <http://example.org/foaf/aliceFoaf> " +
			        	" FROM NAMED <http://example.org/foaf/bobFoaf> " +
			        	" WHERE { " +
			        	" GRAPH ?src " +
			        	"{ ?x foaf:mbox <mailto:bob@work.example> . " +
			        	" ?x foaf:nick ?bobNick " +
			        	"} " +
			        	"}";
			        
			        
			        String queryString2 = "PREFIX foaf: <http://xmlns.com/foaf/0.1/> " +
					"SELECT ?x ?g " +
					" FROM NAMED  <http://example.org/foaf/aliceFoaf> " +
					" FROM NAMED <http://example.org/foaf/bobFoaf> " +
					"WHERE {" +
					"	GRAPH ?g {" +
					"    ?me foaf:name ?x }" +
					"  }";
			        
			        String queryString3 = " PREFIX foaf: <http://xmlns.com/foaf/0.1/> " +
			        		" PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#> " +
			        		" SELECT ?mbox ?nick ?ppd " +
			        		" FROM NAMED <http://example.org/foaf/aliceFoaf> " +
			        		" FROM NAMED <http://example.org/foaf/bobFoaf> " +
			        		" WHERE { " +
			        		" GRAPH <http://example.org/foaf/aliceFoaf> { " +
			        		"?alice foaf:mbox <mailto:alice@work.example> ; " +
			        		" foaf:knows ?whom . " +
			        		" ?whom foaf:mbox ?mbox;" +
			        		" rdfs:seeAlso ?ppd. " +
			        		"?ppd a foaf:PersonalProfileDocument . " +
			        		"}  " +
			        		" GRAPH ?ppd { " +
			        		" ?w foaf:mbox ?mbox; " +
			        		" foaf:nick ?nick " +
			        		"} " +
			        		"}";

					
			        String queryString = queryString3;
					TupleQuery tupleQuery = con.prepareTupleQuery(QueryLanguage.SPARQL, queryString);
					TupleQueryResult result = tupleQuery.evaluate();
					System.out.println("Query:\n" + queryString);
					try {
						//iterate the result set
						while (result.hasNext()) {
							BindingSet bindingSet = result.next();
							System.out.println(bindingSet.toString());
						}
					}
					finally {
						result.close();
					}
				}
				catch (Exception e) {
					//handle exception
					e.printStackTrace();
				} finally {
					con.close();
				}
			}
			catch (OpenRDFException e) {
				// handle exception
				e.printStackTrace();
			}
			
		} catch (RepositoryException e) {
			// handle exception
			e.printStackTrace();
		}
	}
}
